@@ -18,9 +18,9 @@ class RSTExporter(TemplateExporter):
     def _file_extension_default(self):
         return '.rst'
 
-    @default('template_file')
-    def _template_file_default(self):
-        return 'rst.tpl'
+    @default('template_name')
+    def _template_name_default(self):
+        return 'rst'
 
     output_mimetype = 'text/restructuredtext'
     export_from_notebook = "reST"
@@ -35,5 +35,5 @@ class RSTExporter(TemplateExporter):
                 'enabled':True
                 },
             })
-        c.merge(super(RSTExporter,self).default_config)
+        c.merge(super().default_config)
         return c
