@@ -29,13 +29,13 @@ class CheesePreprocessor(Preprocessor):
         """
         Public constructor
         """
-        super(CheesePreprocessor, self).__init__(**kw)
+        super().__init__(**kw)
 
 
     def preprocess(self, nb, resources):
         """
         Sphinx preprocessing to apply on each notebook.
-        
+
         Parameters
         ----------
         nb : NotebookNode
