@@ -4,6 +4,7 @@
 # Distributed under the terms of the Modified BSD License.
 
 import os.path
+from tempfile import TemporaryDirectory
 import textwrap
 import re
 
@@ -14,10 +15,13 @@ from ...tests.utils import onlyif_cmds_exist
 from traitlets.config import Config
 from nbformat import write
 from nbformat import v4
-from testpath.tempdir import TemporaryDirectory
 
 from jinja2 import DictLoader
 
+
+current_dir = os.path.dirname(__file__)
+
+
 class TestLatexExporter(ExportersTestsBase):
     """Contains test functions for latex.py"""
 
@@ -49,23 +53,6 @@ class TestLatexExporter(ExportersTestsBase):
         assert len(output) > 0
 
 
-    @onlyif_cmds_exist('pandoc')
-    def test_export_basic(self):
-        """
-        Can a LatexExporter export using 'article' template?
-        """
-        (output, resources) = LatexExporter(template_file='article').from_filename(self._get_notebook())
-        assert len(output) > 0
-
-
-    @onlyif_cmds_exist('pandoc')
-    def test_export_article(self):
-        """
-        Can a LatexExporter export using 'article' template?
-        """
-        (output, resources) = LatexExporter(template_file='article').from_filename(self._get_notebook())
-        assert len(output) > 0
-
     @onlyif_cmds_exist('pandoc')
     def test_very_long_cells(self):
         """
@@ -100,7 +87,7 @@ class TestLatexExporter(ExportersTestsBase):
             with open(nbfile, 'w') as f:
                 write(nb, f, 4)
 
-            (output, resources) = LatexExporter(template_file='article').from_filename(nbfile)
+            (output, resources) = LatexExporter().from_filename(nbfile)
             assert len(output) > 0
 
     @onlyif_cmds_exist('pandoc')
@@ -110,6 +97,38 @@ class TestLatexExporter(ExportersTestsBase):
         """
         (output, resources) = LatexExporter().from_filename(
             self._get_notebook(nb_name="prompt_numbers.ipynb"))
+        
+        in_regex = r"\\prompt\{In\}\{incolor\}\{(\d+|\s*)\}"
+        out_regex = r"\\prompt\{Out\}\{outcolor\}\{(\d+|\s*)\}"
+
+        ins = ["2", "10", " ", " ",  "0"]
+        outs = ["10"]
+
+        assert re.findall(in_regex, output) == ins
+        assert re.findall(out_regex, output) == outs
+
+    @onlyif_cmds_exist('pandoc')
+    def test_prompt_number_color_ipython(self):
+        """
+        Does LatexExporter properly format input and output prompts in color?
+
+        Uses an in memory latex template to load style_ipython as the cell style.
+        """
+        my_loader_tplx = DictLoader({'my_template': 
+            r"""
+            ((* extends 'style_ipython.tex.j2' *))
+
+            ((* block docclass *))
+            \documentclass[11pt]{article}
+            ((* endblock docclass *))
+            """})
+
+        class MyExporter(LatexExporter):
+            template_file = 'my_template'
+
+        (output, resources) = MyExporter(extra_loaders=[my_loader_tplx]).from_filename(
+            self._get_notebook(nb_name="prompt_numbers.ipynb"))
+        
         in_regex = r"In \[\{\\color\{incolor\}(.*)\}\]:"
         out_regex = r"Out\[\{\\color\{outcolor\}(.*)\}\]:"
 
@@ -118,7 +137,7 @@ class TestLatexExporter(ExportersTestsBase):
 
         assert re.findall(in_regex, output) == ins
         assert re.findall(out_regex, output) == outs
-
+        
     @onlyif_cmds_exist('pandoc')
     def test_no_prompt_yes_input(self):
         no_prompt = {
@@ -134,13 +153,22 @@ class TestLatexExporter(ExportersTestsBase):
             self._get_notebook(nb_name="prompt_numbers.ipynb"))
         assert "shape" in output
         assert "evs" in output
-        
+
+    @onlyif_cmds_exist('pandoc', 'inkscape')
+    def test_svg(self):
+        """
+        Can a LatexExporter export when it recieves raw binary strings form svg?
+        """
+        filename = os.path.join(current_dir, 'files', 'svg.ipynb')
+        (output, resources) = LatexExporter().from_filename(filename)
+        assert len(output) > 0
+
     def test_in_memory_template_tplx(self):
         # Loads in an in memory latex template (.tplx) using jinja2.DictLoader
         # creates a class that uses this template with the template_file argument
         # converts an empty notebook using this mechanism
-        my_loader_tplx = DictLoader({'my_template': "{%- extends 'article.tplx' -%}"})
-        
+        my_loader_tplx = DictLoader({'my_template': "{%- extends 'index' -%}"})
+
         class MyExporter(LatexExporter):
             template_file = 'my_template'
 
