@@ -13,6 +13,7 @@ import logging
 import sys
 import os
 import glob
+import asyncio
 from textwrap import fill, dedent
 from ipython_genutils.text import indent
 
@@ -26,6 +27,7 @@ from traitlets import (
 from traitlets.utils.importstring import import_item
 
 from .exporters.base import get_export_names, get_exporter
+from .exporters.templateexporter import TemplateExporter
 from nbconvert import exporters, preprocessors, writers, postprocessors, __version__
 from .utils.base import NbConvertBase
 from .utils.exceptions import ConversionException
@@ -43,7 +45,7 @@ class DottedOrNone(DottedObjectName):
 
     def validate(self, obj, value):
         if value is not None and len(value) > 0:
-            return super(DottedOrNone, self).validate(obj, value)
+            return super().validate(obj, value)
         else:
             return value
             
@@ -51,7 +53,8 @@ nbconvert_aliases = {}
 nbconvert_aliases.update(base_aliases)
 nbconvert_aliases.update({
     'to' : 'NbConvertApp.export_format',
-    'template' : 'TemplateExporter.template_file',
+    'template' : 'TemplateExporter.template_name',
+    'template-file' : 'TemplateExporter.template_file',
     'writer' : 'NbConvertApp.writer_class',
     'post': 'NbConvertApp.postprocessor_class',
     'output': 'NbConvertApp.output_base',
@@ -120,11 +123,33 @@ nbconvert_flags.update({
         {'TemplateExporter' : {
             'exclude_output_prompt' : True,
             'exclude_input': True,
+            'exclude_input_prompt': True,
             }
         },
         """Exclude input cells and output prompts from converted document. 
         This mode is ideal for generating code-free reports."""
         ),
+    'allow-chromium-download' : (
+        {'WebPDFExporter' : {
+            'allow_chromium_download' : True,
+            }
+        },
+        """Whether to allow downloading chromium if no suitable version is found on the system."""
+        ),
+    'disable-chromium-sandbox': (
+        {'WebPDFExporter': {
+            'disable_sandbox': True,
+            }
+        },
+        """Disable chromium security sandbox when converting to PDF.."""
+        ),
+    'show-input' : (
+        {'TemplateExporter' : {
+            'exclude_input': False,
+            }
+        },
+        """Shows code input. This is flag is only useful for dejavu users."""
+        ),
 })
 
 
@@ -135,7 +160,7 @@ class NbConvertApp(JupyterApp):
     name = 'jupyter-nbconvert'
     aliases = nbconvert_aliases
     flags = nbconvert_flags
-    
+
     @default('log_level')
     def _log_level_default(self):
         return logging.INFO
@@ -178,20 +203,17 @@ class NbConvertApp(JupyterApp):
     examples = Unicode(u"""
         The simplest way to use nbconvert is
         
-        > jupyter nbconvert mynotebook.ipynb
-        
-        which will convert mynotebook.ipynb to the default format (probably HTML).
-        
-        You can specify the export format with `--to`.
+        > jupyter nbconvert mynotebook.ipynb --to html
+
         Options include {formats}.
         
         > jupyter nbconvert --to latex mynotebook.ipynb
 
         Both HTML and LaTeX support multiple output templates. LaTeX includes
-        'base', 'article' and 'report'.  HTML includes 'basic' and 'full'. You
-        can specify the flavor of the format used.
+        'base', 'article' and 'report'.  HTML includes 'basic', 'lab' and 
+        'classic'. You can specify the flavor of the format used.
 
-        > jupyter nbconvert --to html --template basic mynotebook.ipynb
+        > jupyter nbconvert --to html --template lab mynotebook.ipynb
         
         You can also pipe the output to stdout, rather than a file
         
@@ -257,17 +279,12 @@ class NbConvertApp(JupyterApp):
         if new:
             self.postprocessor_factory = import_item(new)
 
-    ipywidgets_base_url = Unicode("https://unpkg.com/",
-                                  help="URL base for ipywidgets package").tag(config=True)
-
-
     export_format = Unicode(
-        'html',
         allow_none=False,
         help="""The export format to be used, either one of the built-in formats
         {formats}
         or a dotted object name that represents the import path for an
-        `Exporter` class""".format(formats=get_export_names())
+        ``Exporter`` class""".format(formats=get_export_names())
     ).tag(config=True)
 
     notebooks = List([], help="""List of notebooks to convert.
@@ -280,8 +297,12 @@ class NbConvertApp(JupyterApp):
     @catch_config_error
     def initialize(self, argv=None):
         """Initialize application, notebooks, writer, and postprocessor"""
+        # See https://bugs.python.org/issue37373 :(
+        if sys.version_info[0] == 3 and sys.version_info[1] >= 8 and sys.platform.startswith('win'):
+            asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
+
         self.init_syspath()
-        super(NbConvertApp, self).initialize(argv)
+        super().initialize(argv)
         self.init_notebooks()
         self.init_writer()
         self.init_postprocessor()
@@ -336,7 +357,7 @@ class NbConvertApp(JupyterApp):
 
     def start(self):
         """Run start after initialization process has completed"""
-        super(NbConvertApp, self).start()
+        super().start()
         self.convert_notebooks()
 
     def init_single_notebook_resources(self, notebook_filename):
@@ -346,7 +367,6 @@ class NbConvertApp(JupyterApp):
 
         Returns
         -------
-
         dict
             resources dictionary for a single notebook that MUST include the following keys:
                 - config_dir: the location of the Jupyter config directory
@@ -376,8 +396,6 @@ class NbConvertApp(JupyterApp):
 
         resources['output_files_dir'] = output_files_dir
 
-        resources['ipywidgets_base_url'] = self.ipywidgets_base_url
-
         return resources
 
     def export_single_notebook(self, notebook_filename, resources, input_buffer=None):
@@ -399,7 +417,6 @@ class NbConvertApp(JupyterApp):
         Returns
         -------
         output
-
         dict
             resources (possibly modified)
         """
@@ -494,16 +511,22 @@ class NbConvertApp(JupyterApp):
                 """
             )
             self.exit(1)
-        
-        # initialize the exporter
-        cls = get_exporter(self.export_format)
-        self.exporter = cls(config=self.config)
 
         # no notebooks to convert!
         if len(self.notebooks) == 0 and not self.from_stdin:
             self.print_help()
             sys.exit(-1)
 
+        if not self.export_format:
+            raise ValueError(
+                "Please specify an output format with '--to <format>'."
+                f"\nThe following formats are available: {get_export_names()}"
+            )
+
+        # initialize the exporter
+        cls = get_exporter(self.export_format)
+        self.exporter = cls(config=self.config)
+
         # convert each notebook
         if not self.from_stdin:
             for notebook_filename in self.notebooks:
@@ -557,8 +580,27 @@ class NbConvertApp(JupyterApp):
 
         return sections.replace(' : ',r' \: ')
             
+
+class DejavuApp(NbConvertApp):
+    def initialize(self, argv=None):
+        self.config.TemplateExporter.exclude_input = True
+        self.config.TemplateExporter.exclude_output_prompt = True
+        self.config.TemplateExporter.exclude_input_prompt = True
+        self.config.ExecutePreprocessor.enabled = True
+        self.config.WebPDFExporter.paginate = False
+
+        super().initialize(argv)
+
+    @default('export_format')
+    def default_export_format(self):
+        return 'html'
+
+class InvalidNotebook(Exception):
+    pass
+
 #-----------------------------------------------------------------------------
 # Main entry point
 #-----------------------------------------------------------------------------
 
 main = launch_new_instance = NbConvertApp.launch_instance
+dejavu_main = DejavuApp.launch_instance
