@@ -6,15 +6,16 @@
 
 import os
 import io
+import nbformat
+from tempfile import TemporaryDirectory
 
 from .base import TestsBase
 from ..postprocessors import PostProcessorBase
 from ..tests.utils import onlyif_cmds_exist
 from nbconvert import nbconvertapp
-from nbconvert.exporters import Exporter
+from nbconvert.exporters import Exporter, HTMLExporter
 
 from traitlets.tests.utils import check_help_all_output
-from testpath import tempdir
 import pytest
 
 #-----------------------------------------------------------------------------
@@ -90,30 +91,44 @@ class TestNbConvertApp(TestsBase):
             assert not os.path.isfile('notebook1.py')
             assert os.path.isfile('notebook2.py')
 
+    def test_clear_output(self):
+        """
+        Can we clear outputs?
+        """
+        with self.create_temp_cwd(['notebook*.ipynb']) as td:
+            self.nbconvert('--clear-output notebook1')
+            assert os.path.isfile('notebook1.ipynb')
+            with open('notebook1.ipynb', encoding='utf8') as f:
+                nb = nbformat.read(f, 4)
+                for cell in nb.cells:
+                    # Skip markdown cells
+                    if 'outputs' in cell:
+                        assert cell.outputs == []
+
     def test_absolute_template_file(self):
-        """--template '/path/to/template.tpl'"""
-        with self.create_temp_cwd(['notebook*.ipynb']), tempdir.TemporaryDirectory() as td:
+        """--template-file '/path/to/template.tpl'"""
+        with self.create_temp_cwd(['notebook*.ipynb']), TemporaryDirectory() as td:
             template = os.path.join(td, 'mytemplate.tpl')
             test_output = 'success!'
             with open(template, 'w') as f:
                 f.write(test_output)
-            self.nbconvert('--log-level 0 notebook2 --template %s' % template)
+            self.nbconvert('--log-level 0 notebook2 --to html --template-file %s' % template)
             assert os.path.isfile('notebook2.html')
-            with open('notebook2.html') as f:
+            with open('notebook2.html', 'r', encoding="utf8") as f:
                 text = f.read()
             assert text == test_output
 
     def test_relative_template_file(self):
-        """Test --template 'relative/path.tpl'"""
+        """Test --template-file 'relative/path.tpl'"""
         with self.create_temp_cwd(['notebook*.ipynb']):
             os.mkdir('relative')
             template = os.path.join('relative', 'path.tpl')
             test_output = 'success!'
             with open(template, 'w') as f:
                 f.write(test_output)
-            self.nbconvert('--log-level 0 notebook2 --template %s' % template)
+            self.nbconvert('--log-level 0 notebook2 --to html --template-file %s' % template)
             assert os.path.isfile('notebook2.html')
-            with open('notebook2.html') as f:
+            with open('notebook2.html', 'r', encoding="utf8") as f:
                 text = f.read()
             assert text == test_output
 
@@ -131,6 +146,18 @@ class TestNbConvertApp(TestsBase):
             )
             assert os.path.isfile('notebook with spaces.pdf')
 
+    @pytest.mark.network
+    def test_webpdf_with_chromium(self):
+        """
+        Generate PDFs if chromium allowed to be downloaded?
+        """
+        with self.create_temp_cwd(['notebook2.ipynb']):
+            self.nbconvert('--to webpdf '
+                           '--allow-chromium-download '
+                           '"notebook2"'
+            )
+            assert os.path.isfile('notebook2.pdf')
+
     @onlyif_cmds_exist('pandoc', 'xelatex')
     def test_pdf(self):
         """
@@ -161,7 +188,7 @@ class TestNbConvertApp(TestsBase):
                 tex = f.read()
             self.nbconvert('--log-level 0 --to html notebook2')
             assert os.path.isfile('notebook2.html')
-            with open('notebook2.html') as f:
+            with open('notebook2.html', 'r', encoding="utf8") as f:
                 html = f.read()
         self.assertEqual(tex.count('\r'), tex.count('\r\n'))
         self.assertEqual(html.count('\r'), html.count('\r\n'))
@@ -171,9 +198,9 @@ class TestNbConvertApp(TestsBase):
         """Is embedded png data well formed in HTML?"""
         with self.create_temp_cwd(['notebook2.ipynb']):
             self.nbconvert('--log-level 0 --to HTML '
-                      'notebook2.ipynb --template full')
+                      'notebook2.ipynb --template lab')
             assert os.path.isfile('notebook2.html')
-            with open('notebook2.html') as f:
+            with open('notebook2.html', 'r', encoding="utf8") as f:
                 assert "data:image/png;base64,b'" not in f.read()
 
     @onlyif_cmds_exist('pandoc')
@@ -185,7 +212,7 @@ class TestNbConvertApp(TestsBase):
             self.nbconvert('--log-level 0 --to slides '
                       'notebook2.ipynb')
             assert os.path.isfile('notebook2.slides.html')
-            with open('notebook2.slides.html') as f:
+            with open('notebook2.slides.html', 'r', encoding="utf8") as f:
                 assert '/reveal.css' in f.read()
 
     def test_output_ext(self):
@@ -260,12 +287,14 @@ class TestNbConvertApp(TestsBase):
                     ' --PDFExporter.verbose=True')
             assert os.path.isfile(u'nb1_análisis.pdf')
 
+    @pytest.mark.skipif(os.name == 'nt', reason='CLI parsing does not work the same on Windows')
     def test_cwd_plugin(self):
         """
         Verify that an extension in the cwd can be imported.
         """
         with self.create_temp_cwd(['hello.py']):
             self.create_empty_notebook(u'empty.ipynb')
+            assert os.path.isfile('hello.py')
             self.nbconvert('empty --to html --NbConvertApp.writer_class=\'hello.HelloWriter\'')
             assert os.path.isfile(u'hello.txt')
 
@@ -308,17 +337,30 @@ class TestNbConvertApp(TestsBase):
         with self.create_temp_cwd(["notebook1.ipynb"]):
             self.nbconvert('notebook1.ipynb --log-level 0 --no-prompt --to html')
             assert os.path.isfile('notebook1.html')
-            with open("notebook1.html",'r') as f:
+            with open("notebook1.html", 'r', encoding="utf8") as f:
                 text = f.read()
                 assert "In&nbsp;[" not in text
-                assert "Out[" not in text
+                assert "Out[6]" not in text
             self.nbconvert('notebook1.ipynb --log-level 0 --to html')
             assert os.path.isfile('notebook1.html')
-            with open("notebook1.html",'r') as f:
+            with open("notebook1.html", 'r', encoding="utf8") as f:
                 text2 = f.read()
                 assert "In&nbsp;[" in text2
-                assert "Out[" in text2
-                
+                assert "Out[6]" in text2
+
+    def test_cell_tag_output(self):
+        """
+        Verify that the html has tags in cell attributes if they exist.
+        """
+        with self.create_temp_cwd(["notebook_tags.ipynb"]):
+            self.nbconvert('notebook_tags.ipynb --log-level 0 --to html')
+            assert os.path.isfile('notebook_tags.html')
+            with open("notebook_tags.html", 'r', encoding="utf8") as f:
+                text = f.read()
+                assert 'celltag_mycelltag celltag_mysecondcelltag' in text
+                assert 'celltag_mymarkdowncelltag' in text
+
+
     def test_no_input(self):
         """
         Verify that the html has no input when given --no-input.
@@ -326,10 +368,10 @@ class TestNbConvertApp(TestsBase):
         with self.create_temp_cwd(["notebook1.ipynb"]):
             self.nbconvert('notebook1.ipynb --log-level 0 --no-input --to html')
             assert os.path.isfile('notebook1.html')
-            with open("notebook1.html",'r') as f:
+            with open("notebook1.html", 'r', encoding="utf8") as f:
                 text = f.read()
                 assert "In&nbsp;[" not in text
-                assert "Out[" not in text
+                assert "Out[6]" not in text
                 assert ('<span class="n">x</span>'
                         '<span class="p">,</span>'
                         '<span class="n">y</span>'
@@ -342,10 +384,10 @@ class TestNbConvertApp(TestsBase):
                         '<span class="p">)</span>') not in text
             self.nbconvert('notebook1.ipynb --log-level 0 --to html')
             assert os.path.isfile('notebook1.html')
-            with open("notebook1.html",'r') as f:
+            with open("notebook1.html", 'r', encoding="utf8") as f:
                 text2 = f.read()
                 assert "In&nbsp;[" in text2
-                assert "Out[" in text2
+                assert "Out[6]" in text2
                 assert ('<span class="n">x</span>'
                         '<span class="p">,</span>'
                         '<span class="n">y</span>'
@@ -434,7 +476,7 @@ class TestNbConvertApp(TestsBase):
                 notebook = f.read().encode()
                 self.nbconvert('--to markdown --stdin', stdin=notebook)
             assert os.path.isfile("notebook.md") # default name for stdin input
-            with io.open('notebook.md') as f:
+            with io.open('notebook.md', 'r', encoding="utf8") as f:
                 output1 = f.read()
                 assert '```python' not in output1 # shouldn't have language
                 assert "```" in output1 # but should have fenced blocks
@@ -469,7 +511,7 @@ class TestNbConvertApp(TestsBase):
             self.nbconvert('--log-level 0 --to markdown '
                            '"markdown_display_priority.ipynb"')
             assert os.path.isfile('markdown_display_priority.md')
-            with io.open('markdown_display_priority.md') as f:
+            with open('markdown_display_priority.md', 'r', encoding="utf8") as f:
                 markdown_output = f.read()
                 assert ("markdown_display_priority_files/"
                         "markdown_display_priority_0_1.png") in markdown_output
@@ -486,7 +528,7 @@ class TestNbConvertApp(TestsBase):
         # check absolute path
         with self.create_temp_cwd(['notebook4_jpeg.ipynb',
                                    'containerized_deployments.jpeg']):
-            output_dir = tempdir.TemporaryDirectory()
+            output_dir = TemporaryDirectory()
             path = os.path.join(output_dir.name, 'files')
             self.nbconvert(
                 '--log-level 0 notebook4_jpeg.ipynb --to rst '
@@ -509,3 +551,49 @@ class TestNbConvertApp(TestsBase):
             self.nbconvert(
                 '--log-level 0 notebook4_jpeg.ipynb --to rst')
             assert fig_exists('notebook4_jpeg_files')
+
+    def test_widgets_from_nbconvert(self):
+        """Check jupyter widgets URL"""
+
+        with self.create_temp_cwd(["Widget_List.ipynb"]):
+            self.nbconvert('Widget_List.ipynb --log-level 0 --to html')
+            assert os.path.isfile('Widget_List.html')
+            with open("Widget_List.html", 'r', encoding="utf8") as f:
+                text = f.read()
+                assert "var widgetRendererSrc = 'https://unpkg.com/@jupyter-widgets/html-manager@*/dist/embed-amd.js';" in text
+
+    def test_widgets_from_htmlexporter(self):
+        """Check jupyter widgets URL"""
+        with self.create_temp_cwd(["Widget_List.ipynb"]) as tmpdir:
+            with open(os.path.join(tmpdir, 'Widget_List.ipynb')) as f:
+                nb = nbformat.read(f, 4)
+
+            output, _ = HTMLExporter().from_notebook_node(nb)
+
+            assert "var widgetRendererSrc = 'https://unpkg.com/@jupyter-widgets/html-manager@*/dist/embed-amd.js';" in output
+
+    def test_execute_widgets_from_nbconvert(self):
+        """Check jupyter widgets render"""
+        notebookName = "Unexecuted_widget"
+        with self.create_temp_cwd([f"{notebookName}.ipynb"]):
+            self.nbconvert(
+                f"{notebookName}.ipynb --execute --log-level 0 --to html")
+            assert os.path.isfile(f"{notebookName}.html")
+            with open(f"{notebookName}.html", "r", encoding="utf8") as f:
+                text = f.read()
+                assert '<script type="application/vnd.jupyter.widget-view+json">' in text
+                assert '<script type="application/vnd.jupyter.widget-state+json">' in text
+
+    def test_execute_multiple_notebooks(self):
+        """Check jupyter widgets render in case of batch convert"""
+        notebookName = "Unexecuted_widget"
+        with self.create_temp_cwd([f"{notebookName}*.ipynb"]):
+            self.nbconvert(
+                "*.ipynb --execute --log-level 0 --to html")
+
+            for name in (notebookName, f"{notebookName}_2"):
+                assert os.path.isfile(f"{name}.html")
+                with open(f"{name}.html", "r", encoding="utf8") as f:
+                    text = f.read()
+                    assert '<script type="application/vnd.jupyter.widget-view+json">' in text
+                    assert '<script type="application/vnd.jupyter.widget-state+json">' in text
